@@ -108,3 +108,23 @@ class FileUtils:
         :return:
         """
         return os.path.exists(target)
+
+    @classmethod
+    def gbk_to_utf8(cls, source, target, callback_line=None, callback_file=None):
+        """
+        Convert a file from GBK to UTF-8.
+        :param source:
+        :param target:
+        :param callback_line:
+        :param callback_file:
+        :return: dst file
+        """
+        with open(source, "r", encoding="gbk") as src:
+            with open(target, "rw", encoding="utf-8") as dst:
+                for line in src.readlines():
+                    if callback_line:
+                        line = callback_line(line)
+                    dst.write(line)
+                if callback_file:
+                    return callback_file(dst)
+                return dst
